@@ -1,7 +1,7 @@
 """
 Type annotations for forecastquery service client.
 
-[Open documentation](./client.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html)
 
 Usage::
 
@@ -40,8 +40,8 @@ class Exceptions:
 
 class ForecastQueryServiceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/forecastquery.html#ForecastQueryService.Client)
-    [Show boto3-stubs documentation](./client.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html)
     """
 
     meta: ClientMeta
@@ -49,8 +49,8 @@ class ForecastQueryServiceClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#can_paginate)
         """
 
     def generate_presigned_url(
@@ -61,19 +61,20 @@ class ForecastQueryServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#generate_presigned_url)
         """
 
     def query_forecast(
         self,
+        *,
         ForecastArn: str,
         Filters: Dict[str, str],
         StartDate: str = None,
         EndDate: str = None,
-        NextToken: str = None,
+        NextToken: str = None
     ) -> QueryForecastResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
-        [Show boto3-stubs documentation](./client.md#query_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#query_forecast)
         """
